==> com.liferay.frontend.editor.tinymce.web-5.0.2.jar: META-INF/resources/_diffs/langs/gl.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('gl', {
	Cut: 'Cortar',
	'Heading 5': 'T\u00edtulo 5',
	'Header 2': 'Cabeceira 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'O seu navegador non admite o acceso directo ao portapapeis. Empregue os atallos de teclado Ctrl+X/C/V no seu canto.',
	'Heading 4': 'T\u00edtulo 4',
	Div: 'Div',
	'Heading 2': 'T\u00edtulo 2',
	Paste: 'Pegar',
	Close: 'Pechar',
	'Font Family': 'Tipo de letra',
	Pre: 'Pre',
	'Align right': 'Ali\u00f1ar \u00e1 dereita',
	'New document': 'Novo documento',
	Blockquote: 'Bloque entre comi\u00f1as',
	'Numbered list': 'Lista numerada',
	'Heading 1': 'T\u00edtulo 1',
	Headings: 'T\u00edtulo',
	'Increase indent': 'Aumentar a sangr\u00eda',
	Formats: 'Formatos',
	Headers: 'Cabeceiras',
	'Select all': 'Seleccionar todo',
	'Header 3': 'Cabeceira 3',
	Blocks: 'Bloques',
	Undo: 'Desfacer',
	Strikethrough: 'Riscado',
	'Bullet list': 'Lista de vi\u00f1etas',
	'Header 1': 'Cabeceira 1',
	Superscript: 'Super\u00edndice',
	'Clear formatting': 'Limpar o formato',
	'Font Sizes': 'Tama\u00f1o da letra',
	Subscript: 'Sub\u00edndice',
	'Header 6': 'Cabeceira 6',
	Redo: 'Refacer',
	Paragraph: 'Par\u00e1grafo',
	Ok: 'Aceptar',
	Bold: 'Negra',
	Code: 'C\u00f3digo',
	Italic: 'Cursiva',
	'Align center': 'Ali\u00f1ar ao centro',
	'Header 5': 'Cabeceira 5',
	'Heading 6': 'T\u00edtulo 6',
	'Heading 3': 'T\u00edtulo 3',
	'Decrease indent': 'Reducir a sangr\u00eda',
	'Header 4': 'Cabeceira 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Neste momento o pegado est\u00e1 definido en modo de texto simple. Os contidos p\u00e9garanse como texto sen formato ata que se active esta opci\u00f3n.',
	Underline: 'Subli\u00f1ado',
	Cancel: 'Cancelar',
	Justify: 'Xustificar',
	Inline: 'En li\u00f1a',
	Copy: 'Copiar',
	'Align left': 'Ali\u00f1ar \u00e1 esquerda',
	'Visual aids': 'Axudas visuais',
	'Lower Greek': 'Grega min\u00fascula',
	Square: 'Cadrado',
	Default: 'Predeterminada',
	'Lower Alpha': 'Alfa min\u00fascula',
	Circle: 'Circulo',
	Disc: 'Disco',
	'Upper Alpha': 'Alfa mai\u00fascula',
	'Upper Roman': 'Romana mai\u00fascula',
	'Lower Roman': 'Romana min\u00fascula',
	Name: 'Nome',
	Anchor: 'Ancoraxe',
	'You have unsaved changes are you sure you want to navigate away?':
		'Ten cambios sen gardar. Confirma que quere sa\u00edr?',
	'Restore last draft': 'Restaurar o \u00faltimo borrador',
	'Special character': 'Car\u00e1cter especial',
	'Source code': 'C\u00f3digo fonte',
	'Right to left': 'De dereita a esquerda',
	'Left to right': 'De esquerda a dereita',
	Emoticons: 'Emoticonas',
	Robots: 'Robots',
	'Document properties': 'Propiedades do documento',
	Title: 'T\u00edtulo',
	Keywords: 'Palabras clave',
	Encoding: 'Codificaci\u00f3n',
	Description: 'Descrici\u00f3n',
	Author: 'Autor',
	Fullscreen: 'Pantalla completa',
	'Horizontal line': 'Li\u00f1a horizontal',
	'Horizontal space': 'Espazo horizontal',
	'Insert/edit image': 'Inserir/editar imaxe',
	General: 'Xeral',
	Advanced: 'Avanzado',
	Source: 'Orixe',
	Border: 'Bordo',
	'Constrain proportions': 'Restrinxir as proporci\u00f3ns',
	'Vertical space': 'Espazo vertical',
	'Image description': 'Descrici\u00f3n da imaxe',
	Style: 'Estilo',
	Dimensions: 'Dimensi\u00f3ns',
	'Insert image': 'Inserir imaxe',
	'Insert date/time': 'Inserir data/hora',
	'Remove link': 'Retirar a ligaz\u00f3n',
	Url: 'URL',
	'Text to display': 'Texto que amosar',
	Anchors: 'Ancoraxes',
	'Insert link': 'Inserir ligaz\u00f3n',
	'New window': 'Nova xanela',
	None: 'Ning\u00fan',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'O URL que introduciu semella seren unha ligaz\u00f3n externa. Quere engadirlle o prefixo http:// requirido?',
	Target: 'Destino',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'O URL que introduciu semella seren un enderezo de correo. Quere engadirlle o prefixo mailto: requirido?',
	'Insert/edit link': 'Inserir/editar ligaz\u00f3n',
	'Insert/edit video': 'Inserir/editar v\u00eddeo',
	Poster: 'Cartel',
	'Alternative source': 'Orixe alternativa',
	'Paste your embed code below:': 'Pegue embaixo o c\u00f3digo integrado:',
	'Insert video': 'Inserir v\u00eddeo',
	Embed: 'Integrado',
	'Nonbreaking space': 'Espazo irromp\u00edbel',
	'Page break': 'Quebra de p\u00e1xina',
	'Paste as text': 'Pegar como texto',
	Preview: 'Vista previa',
	Print: 'Imprimir',
	Save: 'Gardar',
	'Could not find the specified string.':
		'Non foi pos\u00edbel atopar a cadea de texto especificada.',
	Replace: 'Substitu\u00edr',
	Next: 'Seguinte',
	'Whole words': 'Palabras completas',
	'Find and replace': 'Buscar e substitu\u00edr',
	'Replace with': 'Substitu\u00edr con',
	Find: 'Buscar',
	'Replace all': 'Substitu\u00edr todo',
	'Match case': 'Distinguir mai\u00fasculas',
	Prev: 'Anterior',
	Spellcheck: 'Corrector ortogr\u00e1fico',
	Finish: 'Rematar',
	'Ignore all': 'Ignorar todo',
	Ignore: 'Ignorar',
	'Insert row before': 'Inserir unha fila enriba',
	Rows: 'Filas',
	Height: 'Alto',
	'Paste row after': 'Pegar fila enriba',
	Alignment: 'Ali\u00f1amento',
	'Column group': 'Grupo de columnas',
	Row: 'Fila',
	'Insert column before': 'Inserir columna \u00e1 esquerda',
	'Split cell': 'Dividir celas',
	'Cell padding': 'Marxe interior da cela',
	'Cell spacing': 'Marxe entre celas',
	'Row type': 'Tipo de fila',
	'Insert table': 'Inserir t\u00e1boa',
	Body: 'Corpo',
	Caption: 'Subt\u00edtulo',
	Footer: 'Rodap\u00e9',
	'Delete row': 'Eliminar fila',
	'Paste row before': 'Pegar fila embaixo',
	Scope: '\u00c1mbito',
	'Delete table': 'Eliminar t\u00e1boa',
	'H Align': 'Ali\u00f1amento H',
	Top: 'Arriba',
	'Header cell': 'Cela de cabeceira',
	Column: 'Columna',
	'Row group': 'Grupo de filas',
	Cell: 'Cela',
	Middle: 'Medio',
	'Cell type': 'Tipo de cela',
	'Copy row': 'Copiar fila',
	'Row properties': 'Propiedades das filas',
	'Table properties': 'Propiedades da t\u00e1boa',
	Bottom: 'Abaixo',
	'V Align': 'Ali\u00f1amento V',
	Header: 'Cabeceira',
	Right: 'Dereita',
	'Insert column after': 'Inserir columna \u00e1 dereita',
	Cols: 'Cols.',
	'Insert row after': 'Inserir unha fila embaixo',
	Width: 'Largo',
	'Cell properties': 'Propiedades da cela',
	Left: 'Esquerda',
	'Cut row': 'Cortar fila',
	'Delete column': 'Eliminar columna',
	Center: 'Centro',
	'Merge cells': 'Combinar celas',
	'Insert template': 'Inserir modelo',
	Templates: 'Modelos',
	'Background color': 'Cor do fondo',
	'Text color': 'Cor do texto',
	'Show blocks': 'Amosar os bloques',
	'Show invisible characters': 'Amosar caracteres invis\u00edbeis',
	'Words: {0}': 'Palabras: {0}',
	Insert: 'Inserir',
	File: 'Ficheiro',
	Edit: 'Editar',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'\u00c1rea de texto mellorado. Prema ALT-F9 para o men\u00fa. Prema ALT-F10 para a barra de ferramentas. Prema ALT-0 para a axuda',
	Tools: 'Ferramentas',
	View: 'Ver',
	Table: 'T\u00e1boa',
	Format: 'Formato',
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/_diffs/langs/gl.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('gl', {
	'Cut': 'Cortar',
	'Heading 5': 'T\u00edtulo 5',
	'Header 2': 'Cabeceira 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'O seu navegador non admite o acceso directo ao portapapeis. Empregue os atallos de teclado Ctrl+X/C/V no seu canto.',
	'Heading 4': 'T\u00edtulo 4',
	'Div': 'Div',
	'Heading 2': 'T\u00edtulo 2',
	'Paste': 'Pegar',
	'Close': 'Pechar',
	'Font Family': 'Tipo de letra',
	'Pre': 'Pre',
	'Align right': 'Ali\u00f1ar \u00e1 dereita',
	'New document': 'Novo documento',
	'Blockquote': 'Bloque entre comi\u00f1as',
	'Numbered list': 'Lista numerada',
	'Heading 1': 'T\u00edtulo 1',
	'Headings': 'T\u00edtulo',
	'Increase indent': 'Aumentar a sangr\u00eda',
	'Formats': 'Formatos',
	'Headers': 'Cabeceiras',
	'Select all': 'Seleccionar todo',
	'Header 3': 'Cabeceira 3',
	'Blocks': 'Bloques',
	'Undo': 'Desfacer',
	'Strikethrough': 'Riscado',
	'Bullet list': 'Lista de vi\u00f1etas',
	'Header 1': 'Cabeceira 1',
	'Superscript': 'Super\u00edndice',
	'Clear formatting': 'Limpar o formato',
	'Font Sizes': 'Tama\u00f1o da letra',
	'Subscript': 'Sub\u00edndice',
	'Header 6': 'Cabeceira 6',
	'Redo': 'Refacer',
	'Paragraph': 'Par\u00e1grafo',
	'Ok': 'Aceptar',
	'Bold': 'Negra',
	'Code': 'C\u00f3digo',
	'Italic': 'Cursiva',
	'Align center': 'Ali\u00f1ar ao centro',
	'Header 5': 'Cabeceira 5',
	'Heading 6': 'T\u00edtulo 6',
	'Heading 3': 'T\u00edtulo 3',
	'Decrease indent': 'Reducir a sangr\u00eda',
	'Header 4': 'Cabeceira 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Neste momento o pegado est\u00e1 definido en modo de texto simple. Os contidos p\u00e9garanse como texto sen formato ata que se active esta opci\u00f3n.',
	'Underline': 'Subli\u00f1ado',
	'Cancel': 'Cancelar',
	'Justify': 'Xustificar',
	'Inline': 'En li\u00f1a',
	'Copy': 'Copiar',
	'Align left': 'Ali\u00f1ar \u00e1 esquerda',
	'Visual aids': 'Axudas visuais',
	'Lower Greek': 'Grega min\u00fascula',
	'Square': 'Cadrado',
	'Default': 'Predeterminada',
	'Lower Alpha': 'Alfa min\u00fascula',
	'Circle': 'Circulo',
	'Disc': 'Disco',
	'Upper Alpha': 'Alfa mai\u00fascula',
	'Upper Roman': 'Romana mai\u00fascula',
	'Lower Roman': 'Romana min\u00fascula',
	'Name': 'Nome',
	'Anchor': 'Ancoraxe',
	'You have unsaved changes are you sure you want to navigate away?':
		'Ten cambios sen gardar. Confirma que quere sa\u00edr?',
	'Restore last draft': 'Restaurar o \u00faltimo borrador',
	'Special character': 'Car\u00e1cter especial',
	'Source code': 'C\u00f3digo fonte',
	'Right to left': 'De dereita a esquerda',
	'Left to right': 'De esquerda a dereita',
	'Emoticons': 'Emoticonas',
	'Robots': 'Robots',
	'Document properties': 'Propiedades do documento',
	'Title': 'T\u00edtulo',
	'Keywords': 'Palabras clave',
	'Encoding': 'Codificaci\u00f3n',
	'Description': 'Descrici\u00f3n',
	'Author': 'Autor',
	'Fullscreen': 'Pantalla completa',
	'Horizontal line': 'Li\u00f1a horizontal',
	'Horizontal space': 'Espazo horizontal',
	'Insert/edit image': 'Inserir/editar imaxe',
	'General': 'Xeral',
	'Advanced': 'Avanzado',
	'Source': 'Orixe',
	'Border': 'Bordo',
	'Constrain proportions': 'Restrinxir as proporci\u00f3ns',
	'Vertical space': 'Espazo vertical',
	'Image description': 'Descrici\u00f3n da imaxe',
	'Style': 'Estilo',
	'Dimensions': 'Dimensi\u00f3ns',
	'Insert image': 'Inserir imaxe',
	'Insert date/time': 'Inserir data/hora',
	'Remove link': 'Retirar a ligaz\u00f3n',
	'Url': 'URL',
	'Text to display': 'Texto que amosar',
	'Anchors': 'Ancoraxes',
	'Insert link': 'Inserir ligaz\u00f3n',
	'New window': 'Nova xanela',
	'None': 'Ning\u00fan',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'O URL que introduciu semella seren unha ligaz\u00f3n externa. Quere engadirlle o prefixo http:// requirido?',
	'Target': 'Destino',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'O URL que introduciu semella seren un enderezo de correo. Quere engadirlle o prefixo mailto: requirido?',
	'Insert/edit link': 'Inserir/editar ligaz\u00f3n',
	'Insert/edit video': 'Inserir/editar v\u00eddeo',
	'Poster': 'Cartel',
	'Alternative source': 'Orixe alternativa',
	'Paste your embed code below:': 'Pegue embaixo o c\u00f3digo integrado:',
	'Insert video': 'Inserir v\u00eddeo',
	'Embed': 'Integrado',
	'Nonbreaking space': 'Espazo irromp\u00edbel',
	'Page break': 'Quebra de p\u00e1xina',
	'Paste as text': 'Pegar como texto',
	'Preview': 'Vista previa',
	'Print': 'Imprimir',
	'Save': 'Gardar',
	'Could not find the specified string.':
		'Non foi pos\u00edbel atopar a cadea de texto especificada.',
	'Replace': 'Substitu\u00edr',
	'Next': 'Seguinte',
	'Whole words': 'Palabras completas',
	'Find and replace': 'Buscar e substitu\u00edr',
	'Replace with': 'Substitu\u00edr con',
	'Find': 'Buscar',
	'Replace all': 'Substitu\u00edr todo',
	'Match case': 'Distinguir mai\u00fasculas',
	'Prev': 'Anterior',
	'Spellcheck': 'Corrector ortogr\u00e1fico',
	'Finish': 'Rematar',
	'Ignore all': 'Ignorar todo',
	'Ignore': 'Ignorar',
	'Insert row before': 'Inserir unha fila enriba',
	'Rows': 'Filas',
	'Height': 'Alto',
	'Paste row after': 'Pegar fila enriba',
	'Alignment': 'Ali\u00f1amento',
	'Column group': 'Grupo de columnas',
	'Row': 'Fila',
	'Insert column before': 'Inserir columna \u00e1 esquerda',
	'Split cell': 'Dividir celas',
	'Cell padding': 'Marxe interior da cela',
	'Cell spacing': 'Marxe entre celas',
	'Row type': 'Tipo de fila',
	'Insert table': 'Inserir t\u00e1boa',
	'Body': 'Corpo',
	'Caption': 'Subt\u00edtulo',
	'Footer': 'Rodap\u00e9',
	'Delete row': 'Eliminar fila',
	'Paste row before': 'Pegar fila embaixo',
	'Scope': '\u00c1mbito',
	'Delete table': 'Eliminar t\u00e1boa',
	'H Align': 'Ali\u00f1amento H',
	'Top': 'Arriba',
	'Header cell': 'Cela de cabeceira',
	'Column': 'Columna',
	'Row group': 'Grupo de filas',
	'Cell': 'Cela',
	'Middle': 'Medio',
	'Cell type': 'Tipo de cela',
	'Copy row': 'Copiar fila',
	'Row properties': 'Propiedades das filas',
	'Table properties': 'Propiedades da t\u00e1boa',
	'Bottom': 'Abaixo',
	'V Align': 'Ali\u00f1amento V',
	'Header': 'Cabeceira',
	'Right': 'Dereita',
	'Insert column after': 'Inserir columna \u00e1 dereita',
	'Cols': 'Cols.',
	'Insert row after': 'Inserir unha fila embaixo',
	'Width': 'Largo',
	'Cell properties': 'Propiedades da cela',
	'Left': 'Esquerda',
	'Cut row': 'Cortar fila',
	'Delete column': 'Eliminar columna',
	'Center': 'Centro',
	'Merge cells': 'Combinar celas',
	'Insert template': 'Inserir modelo',
	'Templates': 'Modelos',
	'Background color': 'Cor do fondo',
	'Text color': 'Cor do texto',
	'Show blocks': 'Amosar os bloques',
	'Show invisible characters': 'Amosar caracteres invis\u00edbeis',
	'Words: {0}': 'Palabras: {0}',
	'Insert': 'Inserir',
	'File': 'Ficheiro',
	'Edit': 'Editar',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'\u00c1rea de texto mellorado. Prema ALT-F9 para o men\u00fa. Prema ALT-F10 para a barra de ferramentas. Prema ALT-0 para a axuda',
	'Tools': 'Ferramentas',
	'View': 'Ver',
	'Table': 'T\u00e1boa',
	'Format': 'Formato',
});
